.. card::
    :class-title: top-page-title-title
    :class-body: top-page-title-desc
    :text-align: center
    :shadow: none

    .. image:: _static/drain-swamp-banner-640-320.*
        :align: center
        :alt: drain-swamp features build plugins and dependency lock switch

    .. centered:: Python build backend with build plugins and dependency lock switch

    .. raw:: html

        <div class="white-space-20px"></div>

    .. button-ref:: getting_started/index
      :ref-type: doc
      :color: primary
      :shadow:

      Getting Started

    .. button-ref:: getting_started/installation
      :ref-type: doc

.. PYVERSIONS

\* Python 3.9 through 3.13, PyPy

**new in 2.1.x**

fork dependency fixing into separate package; add wreck support;
add pytest-logging-strict support;

**new in 2.0.x**

approach for requirements organize by venvs rather than folders;
new implementation for pipenv-unlock commands;

.. raw:: html

   <div style="visibility: hidden;">

drain-swamp
============

.. raw:: html

   </div>
